aboutsummaryrefslogtreecommitdiff
path: root/src/lib/protocols/socks45.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib/protocols/socks45.c')
-rw-r--r--src/lib/protocols/socks45.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/lib/protocols/socks45.c b/src/lib/protocols/socks45.c
index 3d7d43799..7bc73af2e 100644
--- a/src/lib/protocols/socks45.c
+++ b/src/lib/protocols/socks45.c
@@ -39,8 +39,8 @@ static void ndpi_check_socks4(struct ndpi_detection_module_struct *ndpi_struct,
struct ndpi_packet_struct *packet = &ndpi_struct->packet;
u_int32_t payload_len = packet->payload_packet_len;
- /* Break after 20 packets. */
- if(flow->packet_counter > 20) {
+ /* Break after 10 packets. */
+ if(flow->packet_counter > 10) {
NDPI_EXCLUDE_PROTO(ndpi_struct, flow);
return;
}
@@ -80,8 +80,8 @@ static void ndpi_check_socks5(struct ndpi_detection_module_struct *ndpi_struct,
struct ndpi_packet_struct *packet = &ndpi_struct->packet;
u_int32_t payload_len = packet->payload_packet_len;
- /* Break after 20 packets. */
- if(flow->packet_counter > 20) {
+ /* Break after 10 packets. */
+ if(flow->packet_counter > 10) {
NDPI_EXCLUDE_PROTO(ndpi_struct, flow);
return;
}